pub struct SchemaValue(pub Value);Expand description
A Value that can be produced by any serde deserializer (e.g. serde_json).
This is the bridge between the serde world and tanzim’s own Value type. Deserialize a
schema into a SchemaValue, then feed it to build_value or a Registry.
Tuple Fields
0: ValueImplementations
Sourceimpl SchemaValue
impl SchemaValue