ErrorKind

Enum ErrorKind 

pub enum ErrorKind {
Show 13 variants Type { expected: ValueType, found: ValueType, }, NotConvertible { target: ValueType, found: ValueType, }, Format { expected: &'static str, }, BelowMin { value: String, min: String, }, AboveMax { value: String, max: String, }, TooShort { len: usize, min: usize, }, TooLong { len: usize, max: usize, }, PatternMismatch { pattern: String, }, Duplicate { index: usize, }, MissingKey { key: String, }, UnknownKey { key: String, }, NotAllowed { value: String, }, Either { first: Box<Error>, second: Box<Error>, },
}
What went wrong while validating a value.

Variants



Type

Wrong variant and no coercion applies.

Fields

expected: ValueType


NotConvertible

Right variant family but the contents cannot be coerced to the target.

Fields

target: ValueType


Format

A semantic format check failed (host, email, uuid, …).

Fields

expected: &'static str


BelowMin

Numeric value below the inclusive minimum.

Fields

value: String


AboveMax

Numeric value above the inclusive maximum.

Fields

value: String


TooShort

String/list/map shorter than the minimum length.

Fields

len: usize
min: usize


TooLong

String/list/map longer than the maximum length.

Fields

len: usize
max: usize


PatternMismatch

String did not match the required pattern.

Fields

pattern: String


Duplicate

A duplicate item was found in a list required to be unique.

Fields

index: usize


MissingKey

A required key was missing from a map.

Fields



UnknownKey

A key not declared in the schema was present in a map.

Fields



NotAllowed

A value was not in the allow-list (Enum).

Fields

value: String


Either

Neither alternative of an Either accepted the value.

Fields

first: Box<Error>
second: Box<Error>